# libpythonpro
Módulo para exemplificar construção de projetos python no curso PyTools

Nesse curso é ensinado como contribuir com projetos e código aberto

Link para o curso [Python Pro](https://pythonpro.com.br)

[![Updates](https://pyup.io/repos/github/daanrod/libpythonpro/shield.svg)](https://pyup.io/repos/github/daanrod/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/daanrod/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/daanrod/libpythonpro/)
[![codecov](https://codecov.io/gh/daanrod/libpythonpro/branch/master/graph/badge.svg?token=JVSEH64ZAY)](https://codecov.io/gh/daanrod/libpythonpro)

Suportada versão 3 de Python

Para instalar:
````console
python -m venv .venv
.venv/Scripts/activate (windows)
source .vev/bin/activate (unix)
pip install -r requirements-dev.txt
````

Para conferir qualidade de código:

```console
flake8
```

Topicos a serem abordados:
1. Git
2. Virtualenv
3. Pip
